# Middleware Core API

::: wd.di.middleware.IMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.MiddlewarePipeline
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.ExceptionHandlerMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.LoggingMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.ValidationMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.CachingMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.TNext
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.middleware.TMiddleware
    handler: python
    options:
      show_root_heading: true
      show_source: false
